#!/bin/sh
########################################################################
## detect-system.sh (V0.5.2):
## Common code to detect different Linux distributions/Unices.
## Intended to be used with "Meta Spec Files", i.e. scripts that are 
## supposed to produce a distro specific RPM spec file for a given
## distro.
##
## To use, simply add
##
## source `dirname $0`/detect-system.sh
##
## to your Meta Spec File.
##
##
## Published under GNU Public Licence (GPL)
## (c) Thomas Ribbrock <emgaron@gmx.net> 1999,2000,2001
##
##
## Current Maintainer:	               Thomas Ribbrock <emgaron@gmx.net>
## Original Author:                    Thomas Ribbrock <emgaron@gmx.net>
## Based on an idea from:              Jim Knoble <jmknoble@pobox.com>
########################################################################


########################################################################
## Figuring out what kind of system it is that we're running on
##
HOST_ARCH="`uname -m | sed -e 's%[-/]%_%g'`"
HOST_OS="`uname -s | sed -e 's%[-/]%%g'`"
HOST_OS_VERSION="`uname -r | sed -e 's%[-/]%\.%g'`"
HOST_OS_VARIANT=""
HOST_OS_SUB_VERSION=""
case ${HOST_OS} in
    Linux)
        if [ -f /etc/redhat-release ]; then
	    # this could be either a Red Hat or a Mandrake system - some
	    # Mandrake systems seem to have both /etc/redhat-release *and*
	    # /etc/mandrake-release ?!
	    if [ -f /etc/mandrake-release ]; then
		# Mandrake System
		HOST_OS_VARIANT="Mandrake"
		HOST_OS_SUB_VERSION="`awk '{ print $2 }' </etc/mandrake-release`"
		if [ $HOST_OS_SUB_VERSION = "Mandrake" ]; then
		    HOST_OS_SUB_VERSION="`awk '{ print $4 }' </etc/mandrake-release`"
	    	elif [ $HOST_OS_SUB_VERSION = "Linux" ]; then
			HOST_OS_SUB_VERSION="`awk '{ print $4 }' </etc/mandrake-release`"
		fi
	    else
		# Red Hat System
		HOST_OS_VARIANT="RedHat"
		HOST_OS_SUB_VERSION="`awk '{ print $2 }' </etc/redhat-release`"
		if [ $HOST_OS_SUB_VERSION = "Hat" ]; then
		    HOST_OS_SUB_VERSION="`awk '{ print $5 }' </etc/redhat-release`"
		fi 
	    fi
        elif [ -f /etc/mandrake-release ]; then
	    # Mandrake System - just in case...
            HOST_OS_VARIANT="Mandrake"
	    HOST_OS_SUB_VERSION="`awk '{ print $2 }' </etc/mandrake-release`"
	    if [ $HOST_OS_SUB_VERSION = "Mandrake" ]; then
	        HOST_OS_SUB_VERSION="`awk '{ print $4 }' </etc/mandrake-release`"
	    elif [ $HOST_OS_SUB_VERSION = "Linux" ]; then
		HOST_OS_SUB_VERSION="`awk '{ print $4 }' </etc/mandrake-release`"
	    fi 
	elif [ -f /etc/turbolinux-release ]; then
	    # TurboLinux System???
            HOST_OS_VARIANT="TurboLinux"
	    HOST_OS_SUB_VERSION="`awk '{ print $2 }' </etc/turbolinux-release`"
        elif [ -f /etc/SuSE-release ]; then
	    # supposedly, this only works with SuSE 6.x
	    HOST_OS_VARIANT="SuSE"
	    HOST_OS_SUB_VERSION="`grep VERSION /etc/SuSE-release | awk '{ print $3 }'`"
        elif [ -f /etc/rc.config ]; then
	    # we assume it's SuSE 5.x then
            HOST_OS_VARIANT="SuSE"
            HOST_OS_SUB_VERSION="5.x"
        elif [ -f /etc/.installed ]; then
            # try for Caldera
	    if (grep "OpenLinux" /etc/.installed); then
		# assume it is indeed Caldera
		HOST_OS_VARIANT="COL"
		HOST_OS_SUB_VERSION="`tail -1 /etc/.installed | awk -F - '{print $2 }'`"
	    fi
       	elif [ -f /etc/pld-release ]; then
            # PLD-Linux System
            HOST_OS_VARIANT="PLD"
            HOST_OS_SUB_VERSION="`awk '{ print $1 }' </etc/pld-release`"
        else
            ## Unknown distro
	    HOST_OS_VARIANT="unknown"
	    HOST_OS_SUB_VERSION="unknown"
	fi
	;;        
    AIX)
       ## AIX from IBM
       HOST_OS_VERSION="`uname -a|awk '{print $4"."$3}'`"
       HOST_ARCH="ppc"
#      HOST_OS_VARIANT="IBM"
       ;;
esac
HOST_PLATFORM="${HOST_ARCH}-${HOST_OS}-${HOST_OS_VERSION}"
if [ -n "${HOST_OS_VARIANT}" ]; then
    HOST_PLATFORM="${HOST_PLATFORM}-${HOST_OS_VARIANT}-${HOST_OS_SUB_VERSION}"
fi
echo "I think this system is: $HOST_PLATFORM"
export HOST_ARCH HOST_OS HOST_OS_VERSION HOST_OS_VARIANT HOST_OS_SUB_VERSION
export HOST_PLATFORM

case "${HOST_ARCH}" in
    i*86)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DX86=1"
        ;;
    sparc)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSPARC=1"
        ;;
    alpha)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DALPHA=1"
        ;;
    ppc)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DPPC=1"
        ;;
esac

case "${HOST_PLATFORM}" in
    *Linux*Mandrake-7*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.mdk7"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMDK=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMDK7=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
        ;;
    *Linux*Mandrake-8*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.mdk8"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMDK=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMDK8=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
        ;;
    *Linux*RedHat-7*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl7"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT7=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_DESKTOP=1"
	;;
    *Linux*RedHat-5.9|*Linux*RedHat-6*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl6"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT6=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
	;;
    *Linux*RedHat-5*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl5"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT5=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
	;;
    *Linux*RedHat-4*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl4"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT4=1"
	;;
    *Linux*SuSE-6*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.suse6"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSUSE=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSUSE6=1"
	;;
    *Linux*SuSE-5*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.suse5"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSUSE=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSUSE5=1"
	;;
    *Linux*TurboLinux*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.tl"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DTURBOLINUX=1"
	;;
    *Linux*COL-1*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.col1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DCOL=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DCOL1=1"
	;;
    *Linux*COL-2*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.col2"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DCOL=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DCOL2=1"
	;;
    *Linux*PLD-1*)
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.pld1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DPLD=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DPLD1=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
	;;
    *)
	echo "Hmm ... this appears to be '${HOST_PLATFORM}'"
	echo "I don't know much about that platform."
	echo "Please add support for your platform in an orderly fashion"
	echo "and contact the maintainer of this meta-specfile"
	echo "to merge the changes into it."
        ;;
esac

export PREPROCESSOR_FLAGS

########################################################################
## Change Log
##
##
## 15/10/1999:
## Initial version
##
## 22/01/2000:
## Improved SuSE support (5.x vs. 6.x)
##
## 04/02/2000:
## Added variable SUSE5 and SUSE6 (similar to REDHAT and REDHAT[456])
##
## 10/04/2000:
## Added variable support for Mandrake 7 (MDK and MDK7) - thanks to
##                                        Fabio Coatti <cova@ferrara.linux.it> 
##
## 12/04/2000 (0.3.2):
## Removed MIME_TYPE_FIX, as it is mutt specific. Is now set in spec.in file
##
## 08/07/2000 (0.4.0)
## Added Caldera support - thanks to Matthew R. Kasun <mkasun@ces.on.ca>
##
## 15/07/2000 (0.4.1)
## Improved Caldera support - thanks to Matthew R. Kasun <mkasun@ces.on.ca>
##
## 12/07/2001 (0.5.0)
## Added support for AIX, PLD (and OSF/1 aka True64) by 
##                             Helge Kreutzmann <kreutzm@itp.uni-hannover.de>
## First stab at RHL 7.x support - alpha at this moment, by
##                             Thomas Ribbrock <emgaron@gmx.net>
##
## 08/09/2001 (0.5.1)
## Improved support for RHL 7.x, thanks to
##                              Dominik Mierzejewski <dmierzej@elka.pw.edu.pl>
##
